@@ -1,6 +1,9 @@
 
 # File: planajobv5.py
-# Version = 5
+# Version = 5.1.2
+# There was a bug in version 5.1.1
+
+
 
 
 
@@ -1181,11 +1184,11 @@ def printinvoice(ordnum):
 
 
    content2 = ttk.Frame(root)
-   button= Button (content2, text= "Close", command = txt.destroy)
-   button2 = Button(content2, text = "Use gedit ??", command = usegedit2)
-   content2.grid(column=1, row=0)
-   button2.grid(column=0, row=0)
-   button.grid (column=0, row=1)
+   button=    Button (content2, text= "Close", command = txt.destroy)
+   button2 =  Button (content2, text = "Use gedit ??", command = usegedit2)
+   content2.grid     (column=1, row=0)
+   button2.grid      (column=0, row=0)
+   button.grid       (column=0, row=5)
                    
    txt.grid (column=0, row=7)
 
@@ -1252,11 +1255,11 @@ addcust =          ttk.Button(salesframe,  text=  "Add a customer",
 addsalesord=       ttk.Button(salesframe,  text=  "Add a sales order",          command=addasalesorder )
 listords =         ttk.Button(salesframe,  text=  "List Sales orders",          command = listords)
 addparts=          ttk.Button(salesframe,  text=  "Add parts to a sales order", command=addpartstoorder)
-addlab=            ttk.Button(salesframe,  text = "Add labour to an order",     command=addlabs)
+addlabtoord=            ttk.Button(salesframe,  text = "Add labour to an order",     command=addlabs)
 listpart=          ttk.Button(salesframe,  text=  "List parts on order",        command= listparts)
 listlaborordr=     ttk.Button(salesframe,  text=  "List labour on order",       command= listlabbs)
 issstoktoorder=    ttk.Button(salesframe,  text=  "Issue stock to an order",    command= issstoktoorder)
-addlabtoorder =    ttk.Button(salesframe,  text=  "Add labour to order",        command= addlabourtoorder)
+addlabtoorder =    ttk.Button(salesframe,  text=  "Log labour to order",        command= addlabourtoorder)
 invoiceprint =     ttk.Button(salesframe,  text=  "Print an invoice",           command=invoice)
 
 listsupps =        ttk.Button (purchframe, text=  "List Suppliers",       command = listpurch)
@@ -1283,7 +1286,7 @@ listcust.grid        (column=0, row=3)
 addcust.grid         (column=0, row=4)
 addsalesord.grid     (column=0, row=5)
 addparts.grid        (column=0, row=6)
-addlab.grid          (column=0, row=7)
+addlabtoord.grid     (column=0, row=7)
 listords.grid        (column=0, row=8)
 listpart.grid        (column=0, row=9)
 listlaborordr.grid   (column=0, row=10)
